@@ -37,16 +37,31 @@ def reconnect(name):
 
 fout = None
 
+def normalize_output(output):
+  status = output[0]
+  if status:
+    normalized_start_time = 1337566253.89858
+    normalized_elapsed_time = 0.000355720520019531
+    status[1] = normalized_start_time
+    status[2] = normalized_elapsed_time
+  return output
+
 def execmd(command, fout):
-  formatted_command_line = '> ' + command + "\n"
-  stdout.write(formatted_command_line)
+  stdout.write(command + "\n")
   stdout.flush()
   groonga_process.stdin.write(command + "\n")
   groonga_process.stdin.flush()
+  is_command = re.match("[a-z/]", command)
+  is_console = not re.match("/", command)
   if fout:
-    fout.write(formatted_command_line + "  ")
-  is_command = re.match("[a-z]", command)
-  if not is_command:
+    if is_console:
+      prefix = "  "
+    else:
+      prefix = "  % curl http://localhost:10041"
+    formatted_command_line = prefix + command + "\n"
+    fout.write(formatted_command_line)
+  is_load_data_end = re.match("^\]", command)
+  if not is_command and not is_load_data_end:
     return
   output_buffer = ""
   while True:
@@ -60,18 +75,26 @@ def execmd(command, fout):
       else:
         output_buffer += char
         if char == '\n':
+          parsed_output = json.loads(output_buffer)
+          normalized_output = normalize_output(parsed_output)
           if len(output_buffer) < 80:
-            formatted_output = output_buffer
+            formatted_output = json.dumps(normalized_output,
+                                          ensure_ascii=False)
           else:
-            parsed_output = json.loads(output_buffer)
-            formatted_output = json.dumps(parsed_output,
+            formatted_output = json.dumps(normalized_output,
                                           indent=2,
                                           ensure_ascii=False)
             formatted_output += "\n"
             formatted_output = formatted_output.encode("utf-8")
           stdout.write(formatted_output)
           if fout:
-            fout.write(re.sub("\n", "\n  ", formatted_output))
+            if is_console:
+              prefix = "  # "
+            else:
+              prefix = "  "
+            first_lines_re = re.compile("^", re.M)
+            fout.write(first_lines_re.sub(prefix, formatted_output.strip()))
+            fout.write("\n")
           output_buffer = ""
     else:
       stdout.flush()
@@ -79,7 +102,7 @@ def execmd(command, fout):
 
 processed_files = []
 def readfile(fname, outflag):
-  if fname in processed_files:
+  if outflag > 0 and fname in processed_files:
     print "skipped processed file: %s" % fname
     return
   if outflag > 32:
@@ -116,20 +139,20 @@ def readfile(fname, outflag):
               os.makedirs(dir_name)
             fout = open(a, 'w')
             print '### write start : ' + a
-            fout.write("Execution example::\n\n  ")
+            fout.write("Execution example::\n\n")
         elif cmd.startswith('.. % '):
-          a = cmd[5:]
+          command_line = cmd[5:]
           if fout:
-            fout.write(a + "\n  ")
-          print a
-          os.system(a)
+            fout.write("  " + command_line + "\n")
+          print command_line
+          os.system(command_line)
         elif cmd.startswith('.. .. '):
-          a = cmd[6:]
+          command_line = cmd[6:]
           if fout:
-            fout.write(a + "\n  ")
-          print a
+            fout.write("  " + command_line + "\n")
+          print command_line
         elif cmd.startswith('..'):
-          if cmd.replace(' ','').replace("\t",'') == '..':
+          if cmd.replace(' ', '').replace("\t", '') == '..':
             while len(dat):
               if dat[0] == '' or (dat[0][0] != ' ' and dat[0][0] != '	'):
                 break
