@@ -12,7 +12,7 @@
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #ifndef GRN_DAT_ID_CURSOR_HPP_
@@ -25,7 +25,7 @@ namespace dat {
 
 class Trie;
 
-class IdCursor : public Cursor {
+class GRN_DAT_API IdCursor : public Cursor {
  public:
   IdCursor();
   ~IdCursor();
