@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 
 export BASE_DIR="`dirname $0`"
 if test -z "$BUILD_DIR"; then
@@ -23,6 +23,11 @@ if test -z "$GROONGA"; then
 fi
 export GROONGA
 
+if test -z "$GROONGA_HTTPD"; then
+    GROONGA_HTTPD="`make -s -C $top_dir echo-groonga-httpd`"
+fi
+export GROONGA_HTTPD
+
 if test -z "$GROONGA_SUGGEST_CREATE_DATASET"; then
     GROONGA_SUGGEST_CREATE_DATASET="`make -s -C $top_dir echo-groonga-suggest-create-dataset`"
 fi
@@ -50,15 +55,39 @@ if ! test -d "$grntest_dir"; then
     git clone git://github.com/groonga/grntest.git "$grntest_dir"
 fi
 
-if test $# -eq 0; then
-    targets="$BASE_DIR/suite"
-else
-    targets=
+have_targets="false"
+next_argument_is_long_option_value="false"
+for argument in "$@"; do
+    case "$argument" in
+	--*=*)
+	    ;;
+	--keep-database|--no-*|--version|--help)
+	    # no argument options
+	    ;;
+	--*)
+	    next_argument_is_long_option_value="true"
+	    continue
+	    ;;
+	-*)
+	    ;;
+	*)
+	    if test "$next_argument_is_long_option_value" != "true"; then
+		have_targets="true"
+	    fi
+	    ;;
+    esac
+    next_argument_is_long_option_value="false"
+done
+
+grntest_options=("$@")
+if test "$have_targets" != "true"; then
+    grntest_options=("${grntest_options[@]}" "${BASE_DIR}/suite")
 fi
 
 $RUBY -I "$grntest_dir/lib" \
     "$grntest_dir/bin/grntest" \
     --groonga "$GROONGA" \
+    --groonga-httpd "$GROONGA_HTTPD" \
     --groonga-suggest-create-dataset "$GROONGA_SUGGEST_CREATE_DATASET" \
     --base-directory "$BASE_DIR" \
-    "$targets" "$@"
+    "${grntest_options[@]}"
